@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: affile.c,v 1.31.2.6 2002/09/27 08:47:58 bazsi Exp $
+ * $Id: affile.c,v 1.31.2.7 2002/10/28 10:23:15 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -470,6 +470,11 @@ void expand_macro(struct syslog_config *cfg, int id, char **dest, int *left, str
 	default:
 		break;
 	}
+	
+	if (length < 0 || length > *left) {
+		length = *left;
+	}
+	
 	*left -= length;
 	*dest += length;
 }
@@ -492,7 +497,7 @@ expand_macros(struct syslog_config *cfg, struct ol_string *template, struct log_
 		{ "WEEKDAY", 'w' }
 	};
 	char format[MAX_EXPANDED_MACRO], *format_ptr = format;
-	int left = sizeof(format);
+	int left = sizeof(format) - 1;
 	int i, j;
 
 	i = 0;
