@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afinet.c,v 1.6.4.4 2001/10/19 12:44:59 bazsi Exp $
+ * $Id: afinet.c,v 1.6.4.5 2002/03/28 11:41:29 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -376,14 +376,14 @@ void afinet_dest_set_localip(struct log_dest_driver *c, const char *ip)
 {
 	CAST_SUBTYPE(afsocket_dest, dest, c);
 
-	inet_address_setip(&dest->dest_addr, ip);
+	inet_address_setip(&dest->bind_addr, ip);
 }
 
 void afinet_dest_set_localport(struct log_dest_driver *c, UINT32 port)
 {
 	CAST_SUBTYPE(afsocket_dest, dest, c);
 
-	inet_address_setport(&dest->dest_addr, port);
+	inet_address_setport(&dest->bind_addr, port);
 }
 
 void afinet_dest_set_destport(struct log_dest_driver *c, UINT32 port)
