@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: afsocket.c,v 1.20.2.1 2001/02/25 12:30:22 bazsi Exp $
+ * $Id: afsocket.c,v 1.20.2.2 2001/07/11 14:08:16 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -86,7 +86,7 @@ do_accept_socket_connection(struct fd_listen_callback *c,
 {
 	CAST(afsocket_accept_callback, self, c);
 	return SOURCE_OPEN_CONNECTION(self->source, 
-				      make_io_fd(self->backend, fd),
+				      make_io_fd(self->backend, fd, NULL),
 				      a);
 }
 
@@ -134,7 +134,7 @@ static int do_afsocket_dest_connected(struct fd_callback **r, int fd)
 {
 	CAST(afsocket_dest_connected, self, *r);
 	
-	return DESTINATION_CONNECTED(self->dest, fd != -1 ? make_io_fd(self->backend, fd) : NULL);
+	return DESTINATION_CONNECTED(self->dest, fd != -1 ? make_io_fd(self->backend, fd, NULL) : NULL);
 
 }
 
