@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: filters.c,v 1.12.2.2 2001/02/25 12:30:22 bazsi Exp $
+ * $Id: filters.c,v 1.12.2.3 2001/05/16 07:13:57 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -260,15 +260,15 @@ static int do_filter_call(struct filter_expr_node *c,
 	if (!self->call_rule) {
 		struct log_filter *p = rule->prev_filter;
 		while (p && 
-		       p->name->length != self->name->length &&
-		       memcmp(p->name->data, self->name->data, self->name->length)) {
+		       (p->name->length != self->name->length ||
+		        memcmp(p->name->data, self->name->data, self->name->length))) {
 			p = p->prev_filter;
 		}
 		if (!p) {
 			p = rule->next_filter;
 			while (p && 
-			       p->name->length != self->name->length &&
-			       memcmp(p->name->data, self->name->data, self->name->length)) {
+			       (p->name->length != self->name->length ||
+			        memcmp(p->name->data, self->name->data, self->name->length))) {
 				p = p->next_filter;
 			}
 			
