@@ -19,7 +19,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: log.c,v 1.19.4.4 2001/10/19 12:44:59 bazsi Exp $
+ * $Id: log.c,v 1.19.4.5 2002/10/28 10:23:15 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -157,7 +157,7 @@ static void parse_log_msg(struct log_info *lm, UINT32 length, UINT8 *data)
 		lm->stamp = now;
 	}
 
-	for (oldsrc = src, oldleft = left; oldleft >= 0; oldleft--, oldsrc++) {
+	for (oldsrc = src, oldleft = left; oldleft > 0; oldleft--, oldsrc++) {
 		if (*oldsrc == '\n' || *oldsrc == '\r') *oldsrc = ' ';
 	}
 	lm->msg = c_format_cstring("%s", left, src);
